package com.flow.flowable.converter;

import com.flow.flowable.model.CopyServiceTask;
import com.flow.flowable.model.JumpServiceTask;
import com.flow.flowable.utils.ProcessElementUtil;
import org.flowable.bpmn.converter.ServiceTaskXMLConverter;
import org.flowable.bpmn.model.BaseElement;
import org.flowable.bpmn.model.BpmnModel;
import org.flowable.bpmn.model.ServiceTask;

import javax.xml.stream.XMLStreamReader;

public class CustomServiceTaskXMLConverter extends ServiceTaskXMLConverter {
    public CustomServiceTaskXMLConverter() {
    }


    @Override
    protected BaseElement convertXMLToElement(XMLStreamReader xtr, BpmnModel model) throws Exception {
        BaseElement baseElement = super.convertXMLToElement(xtr, model);
        if (baseElement instanceof ServiceTask) {
            ServiceTask serviceTask = (ServiceTask) baseElement;
            String serviceTaskType = serviceTask.getType();
            if ("copy".equals(serviceTaskType)) {
                CopyServiceTask copyServiceTask = new CopyServiceTask();
                copyServiceTask.setValues(serviceTask);
                this.convertCopyServiceTaskXMLProperties(copyServiceTask, model, xtr);
                return copyServiceTask;
            } else if ("jump".equals(serviceTaskType)) {
                JumpServiceTask jumpServiceTask = new JumpServiceTask();
                jumpServiceTask.setValues(serviceTask);
                this.convertJumpServiceTaskXMLProperties(jumpServiceTask, model, xtr);
                return jumpServiceTask;
            }
        }
        return baseElement;
    }

    protected void convertCopyServiceTaskXMLProperties(CopyServiceTask copyServiceTask, BpmnModel bpmnModel, XMLStreamReader xtr) throws Exception {
        String assignee = ProcessElementUtil.getFieldExtensionExpression(copyServiceTask, "assignee");
        copyServiceTask.setAssignee(assignee);
    }

    protected void convertJumpServiceTaskXMLProperties(JumpServiceTask jumpServiceTask, BpmnModel bpmnModel, XMLStreamReader xtr) throws Exception {
        String targetNode = ProcessElementUtil.getFieldExtensionValue(jumpServiceTask, "targetNode");
        jumpServiceTask.setTargetNode(targetNode);
    }
}
